@@ -4,6 +4,12 @@
 *
 * @author Christophe Dutang
 *
+* Copyright (C) 2022, Christophe Dutang
+* # remove a warning: this old-style function definition is not preceded by a prototype
+* # raised by 
+* > clang -DNDEBUG   -isystem /usr/local/clang15/include                                      \
+* -I"/Library/Frameworks/R.framework/Headers"  -fpic  -O3 -Wall -pedantic -Wstrict-prototypes \
+* -c LowDiscrepancy-halton.c -o LowDiscrepancy-halton.o
 *
 * Copyright (C) Aug. 2016, Christophe Dutang, C translation of a previous code
 *
@@ -103,7 +109,7 @@ double HALTONREC(int DIMEN, unsigned long long OFFSET)
 }
 
 #include "primes.h"
-void reconstruct_prime()
+void reconstruct_prime(void)
 {
   int i;
   if (primeNumber[2] == 1)
