@@ -1,43 +1,43 @@
 library(randtoolbox)
 
 #simple check
-umat <- sobol(n=1e5, dim=1111)
+umat <- sobol(n=5, dim=1111)
 sum(umat > 1 | umat < 0)
 
-#Kemal Dincer, bug report
-umat<- sobol(n=2^15,dim=12,scrambling=3,seed=1776)
-sum(umat > 1)
-umat <- sobol(n=2^10,dim=12,scrambling=1,seed=5742)
-sum(umat > 1)
-umat <- sobol(n=2^15,dim=12,scrambling=1,seed=1716)
-sum(umat > 1)
-umat <- sobol(n=2^15,dim=22,scrambling=2,seed=12345678)
-sum(umat >= 1)
-
-
-#Dan Southern, bug report
-umat <- sobol(n=2000, dim=13, seed=832121780, scrambling = 1)
-sum(umat > 1)
-
-#Marius Hofert, bug report
-umat <- sobol(2e5, dim=10, scrambling=1, seed=2185)
-sum(umat > 1)
-
-#Nicolas Chopin, bug report
-umat <- sobol(2000,dim=2,seed=1352,scrambling=1)
-sum(umat > 1)
-
-#Makoto Matsumoto and Mutsuo Saito, bug report
+#bug report check
 if(FALSE)
 {
+  #Kemal Dincer, bug report
+  umat<- sobol(n=2^15,dim=12,scrambling=3,seed=1776)
+  sum(umat > 1)
+  umat <- sobol(n=2^10,dim=12,scrambling=1,seed=5742)
+  sum(umat > 1)
+  umat <- sobol(n=2^15,dim=12,scrambling=1,seed=1716)
+  sum(umat > 1)
+  umat <- sobol(n=2^15,dim=22,scrambling=2,seed=12345678)
+  sum(umat >= 1)
+  
+  
+  #Dan Southern, bug report
+  umat <- sobol(n=2000, dim=13, seed=832121780, scrambling = 1)
+  sum(umat > 1)
+  
+  #Marius Hofert, bug report
+  umat <- sobol(2e5, dim=10, scrambling=1, seed=2185)
+  sum(umat > 1)
+  
+  #Nicolas Chopin, bug report
+  umat <- sobol(2000,dim=2,seed=1352,scrambling=1)
+  sum(umat > 1)
+  
+  #Makoto Matsumoto and Mutsuo Saito, bug report
   n <- 10^8
   umat <- sobol(n, dim = 3, init =TRUE, scrambling = 1)
   sum(umat > 1)
-}
-
-# guido gruetzner bug report
-if(FALSE)
-{
+  
+  
+  # guido gruetzner bug report
+  
   umat <- sobol(10, dim=1, init=TRUE, seed=4711, scrambling=1)
   sum(umat >1)
   tt <- sobol(500, dim = 80, init = FALSE, scrambling = 1)
@@ -105,5 +105,5 @@ figsimsobcheck = function(fn="figsimsobcheck.pdf", export=TRUE){
     dev.off()
 }
 if(FALSE)
-figsimsobcheck(export=FALSE)
+  figsimsobcheck(export=FALSE)
 
